Skip to contents

Scales colour with a binned colour scale, and additionally maps fill to a blended version of the resulting colour, via aes_fillblend(). The fill legend is suppressed since colour already communicates the mapping.

Usage

scale_colour_fillblend_binned(blend = NULL, ...)

Arguments

blend

A function that takes a colour vector and returns a blended colour vector.

...

Additional arguments passed on to ggplot2::scale_colour_binned(), and ggplot2::scale_fill_binned().

Value

A list of ggplot2 components (a mapping, a binned colour/fill scale, and a guide) that can be added to a ggplot object.