Skip to contents

Scales colour with a continuous colour scale, and additionally maps fill to a blended version of the resulting colour, via aes_fillblend(). The fill legend is suppressed since colour already communicates the mapping.

Usage

scale_colour_fillblend_continuous(blend = NULL, ...)

Arguments

blend

A function that takes a colour vector and returns a blended colour vector.

...

Additional arguments passed on to ggplot2::scale_colour_continuous(), and ggplot2::scale_fill_continuous().

Value

A list of ggplot2 components (a mapping, a continuous colour/fill scale, and a guide) that can be added to a ggplot object.