Scale fill, and derive colour by blending (binned)
Source:R/scale-blend.R
scale_fill_colourblend_binned.RdScales fill with a binned colour scale, and additionally maps colour
to a blended version of the resulting fill, via aes_colourblend().
The colour legend is suppressed since fill already communicates the
mapping.
Arguments
- blend
A function that takes a colour vector and returns a blended colour vector.
- ...
Additional arguments passed on to
ggplot2::scale_colour_binned(), andggplot2::scale_fill_binned().