Skip to contents

Scales fill with a continuous colour scale, and additionally maps colour to a blended version of the resulting fill, via aes_colourblend(). The colour legend is suppressed since fill already communicates the mapping.

Usage

scale_fill_colourblend_continuous(blend = NULL, ...)

Arguments

blend

A function that takes a colour vector and returns a blended colour vector.

...

Additional arguments passed on to ggplot2::scale_colour_continuous(), and ggplot2::scale_fill_continuous().

Value

A list of ggplot2 components (a mapping, a continuous colour/fill scale, and a guide) that can be added to a ggplot object.