Modifies active theme settings for fixed, discrete, and continuous palettes only for parameters explicitly provided by the user.
Arguments
- fixed
Colour applied to geometric elements via
element_geom(). Updates bothcolourandfill.- discrete
Palette specification (e.g.,
scales::pal_hue()) for discrete scales (palette.colour.discreteandpalette.fill.discrete).- continuous
Palette specification for continuous scales (
palette.colour.continuousandpalette.fill.continuous).
Value
Invisibly returns the result of the theme_update() calls.
Examples
if (FALSE) { # \dontrun{
# Update fixed geom colour
update_palette(fixed = "steelblue")
# Update discrete palette
update_palette(discrete = scales::pal_hue())
# Update continuous palette
update_palette(continuous = scales::pal_viridis())
} # }