Skip to contents

Modifies panel dimensions such as heights and widths by updating the global theme settings.

Usage

update_panel_size(heights = ggplot2::waiver(), widths = ggplot2::waiver())

Arguments

heights

A margin or unit object specifying the panel heights (e.g., grid::unit(5, "cm")).

widths

A margin or unit object specifying the panel widths (e.g., grid::unit(5, "cm")).

Value

Invisibly returns the updated theme object.

Examples

if (FALSE) { # \dontrun{
update_panel_size(
  heights = grid::unit(6, "cm"),
  widths = grid::unit(8, "cm")
)
} # }