Removes all axis lines, ticks, and minor ticks, and removes all axis text and axis titles. Removes panel gridlines on the orientation axis only when at least one axis is discrete.
Arguments
- ...
Reserved for future extensions. Placed first so later arguments must be named, and to support trailing commas in calls.
- discrete
Character scalar describing which axes should be treated as discrete for refinement purposes:
"none","x","y", or"both".- orientation
Character. The primary axis of interest:
"x"or"y". This affects grid modes such as*_drift()and*_flow(). IfNULL(default), orientation is inferred fromdiscrete:"y"gives"y", otherwise"x".