| minimal | R Documentation |
Behaves like hybrid() but additionally removes axis lines and
ticks from both axes. When both axes are continuous or binned, only axis
lines and ticks are removed, leaving gridlines untouched. When a discrete
axis is present, also removes gridlines and axis elements from the
non-focused dimension, as in modern().
minimal(x_type = "continuous", y_type = "continuous", focus = NULL, ...)
x_type |
Character. Type of x-axis: "continuous", "binned", or "discrete". |
y_type |
Character. Type of y-axis: "continuous", "binned", or "discrete". |
focus |
Character. The primary axis of interest: "x" or "y". Gridlines
and axis elements are removed from the opposite axis. If |
... |
Additional arguments (currently unused). |
A ggplot2 theme object
library(ggplot2)
set_theme(new = ggrefine::theme_grey())
p_continuous <- mpg |>
ggplot(aes(x = displ, y = hwy)) +
geom_point(shape = 21, colour = blends::multiply("#357BA2FF"))
p_discrete_x <- mpg |>
ggplot(aes(x = drv, y = hwy)) +
geom_jitter(shape = 21, colour = blends::multiply("#357BA2FF"))
p_discrete_y <- mpg |>
ggplot(aes(x = hwy, y = drv)) +
geom_jitter(shape = 21, colour = blends::multiply("#357BA2FF"))
patchwork::wrap_plots(
p_continuous + ggrefine::classic() + labs(title = "ggrefine::classic"),
p_discrete_x + ggrefine::classic(x_type = "discrete"),
p_discrete_y + ggrefine::classic(y_type = "discrete"),
p_continuous + ggrefine::modern() + labs(title = "ggrefine::modern"),
p_discrete_x + ggrefine::modern(x_type = "discrete"),
p_discrete_y + ggrefine::modern(y_type = "discrete"),
p_continuous + ggrefine::hybrid() + labs(title = "ggrefine::hybrid"),
p_discrete_x + ggrefine::hybrid(x_type = "discrete"),
p_discrete_y + ggrefine::hybrid(y_type = "discrete"),
p_continuous + ggrefine::minimal() + labs(title = "ggrefine::minimal"),
p_discrete_x + ggrefine::minimal(x_type = "discrete"),
p_discrete_y + ggrefine::minimal(y_type = "discrete"),
p_continuous + ggrefine::void() + labs(title = "ggrefine::void"),
p_discrete_x + ggrefine::void(x_type = "discrete"),
p_discrete_y + ggrefine::void(y_type = "discrete"),
p_continuous + ggrefine::none() + labs(title = "ggrefine::none"),
p_discrete_x + ggrefine::none(x_type = "discrete"),
p_discrete_y + ggrefine::none(y_type = "discrete"),
ncol = 3
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.