Scale colour, and derive fill by blending (binned)
Source:R/scale-blend.R
scale_colour_fillblend_binned.RdScales colour with a binned colour scale, and additionally maps fill
to a blended version of the resulting colour, via aes_fillblend().
The fill legend is suppressed since colour already communicates the
mapping.
Arguments
- blend
A function that takes a colour vector and returns a blended colour vector.
- ...
Additional arguments passed on to
ggplot2::scale_colour_binned(), andggplot2::scale_fill_binned().