Scale colour, and derive fill by blending (continuous)
Source:R/scale-blend.R
scale_colour_fillblend_continuous.RdScales colour with a continuous colour scale, and additionally maps
fill to a blended version of the resulting colour, via
aes_fillblend(). The fill legend is suppressed since colour
already communicates the mapping.
Arguments
- blend
A function that takes a colour vector and returns a blended colour vector.
- ...
Additional arguments passed on to
ggplot2::scale_colour_continuous(), andggplot2::scale_fill_continuous().