Scale fill, and derive colour by blending (continuous)
Source:R/scale-blend.R
scale_fill_colourblend_continuous.RdScales fill with a continuous colour scale, and additionally maps
colour to a blended version of the resulting fill, via
aes_colourblend(). The colour legend is suppressed since fill
already communicates the mapping.
Arguments
- blend
A function that takes a colour vector and returns a blended colour vector.
- ...
Additional arguments passed on to
ggplot2::scale_colour_continuous(), andggplot2::scale_fill_continuous().