A complete theme for a dark plot and panel background. The plot
background defaults to "black", and the panel grid colour defaults to
plot_background_fill.
Usage
theme_dark(
...,
text_size = 10,
text_family = "",
text_colour = flexoki::flexoki$base["base200"],
title_size = NULL,
title_family = NULL,
title_colour = NULL,
subtitle_size = NULL,
subtitle_family = NULL,
subtitle_colour = NULL,
caption_size = NULL,
caption_family = NULL,
caption_colour = NULL,
caption_hjust = 0,
legend_place = "right",
legend_axis_line_colour = NULL,
legend_axis_line_linewidth = NULL,
legend_background_fill = NULL,
legend_key_fill = NULL,
legend_ticks_colour = NULL,
legend_ticks_linewidth = NULL,
legend_ticks_length = grid::unit(c(2.75, 0), "pt"),
axis_line_colour = NULL,
axis_line_linewidth = 0.2,
axis_ticks_colour = NULL,
axis_ticks_linewidth = NULL,
axis_ticks_length = grid::unit(3.66, "pt"),
panel_background_fill = flexoki::flexoki$base["base950"],
panel_grid_colour = NULL,
panel_grid_linetype = 1,
panel_grid_linewidth = 1,
panel_grid_minor_linetype = 1,
panel_grid_minor_linewidth = 0.5,
plot_background_fill = "black",
panel_widths = NULL,
panel_heights = NULL
)Arguments
- ...
Require named arguments (and support trailing commas).
- text_size
The base size of the text theme element. Defaults to 10.
- text_family
The base family of the text theme element. Defaults to "".
- text_colour
The base colour of the text theme element.
- title_size
The size of the
plot.titletheme element. Defaults totext_size.- title_family
The family of the
plot.titletheme element. Defaults totext_family.- title_colour
The colour of the
plot.titletheme element. Defaults totext_colour.- subtitle_size
The size of the
plot.subtitletheme element. Defaults totext_size.- subtitle_family
The family of the
plot.subtitletheme element. Defaults totext_family.- subtitle_colour
The colour of the
plot.subtitletheme element. Defaults totext_colour.- caption_size
The size of the
plot.captiontheme element. Defaults totext_size.- caption_family
The family of the
plot.captiontheme element. Defaults totext_family.- caption_colour
The colour of the
plot.captiontheme element. Defaults totext_colour.- caption_hjust
The horizontal justification of the
plot.captiontheme element. Defaults to 0.- legend_place
The place of the legend. Either "right", "top" or "bottom".
- legend_axis_line_colour
The colour of the legend.axis.line theme element.
- legend_axis_line_linewidth
The linewidth of the legend.axis.line theme element.
- legend_background_fill
The fill (and colour) of the
legend.backgroundtheme element.- legend_key_fill
The fill (and colour) of the legend.key theme element.
- legend_ticks_colour
The colour of the legend.ticks theme element.
- legend_ticks_linewidth
The linewidth of the legend.ticks theme element.
- legend_ticks_length
The length of the legend.ticks.length theme element.
- axis_line_colour
The colour of the axis.line theme element. Defaults to
text_colour.- axis_line_linewidth
The linewidth of the axis.line theme element.
- axis_ticks_colour
The colour of the axis.ticks theme element.
- axis_ticks_linewidth
The linewidth of the axis.ticks theme element.
- axis_ticks_length
The length of the axis.ticks.length theme element.
- panel_background_fill
The fill (and colour) of the panel.background theme element.
- panel_grid_colour
The colour of the panel.grid theme element.
- panel_grid_linetype
The linetype of the panel.grid.major theme element.
- panel_grid_linewidth
The linewidth of the panel.grid.major theme element.
- panel_grid_minor_linetype
The linetype of the panel.grid.minor theme element.
- panel_grid_minor_linewidth
The linewidth of the panel.grid.minor theme element.
- plot_background_fill
The fill (and colour) of the plot.background theme element.
- panel_widths
The panel.widths theme element. A
unitor unit vector setting the width of individual panels, or a single unit for the total panel area width. Overrides aspect ratio set by the theme, coord, or facets. Defaults toNULL.- panel_heights
The panel.heights theme element. A
unitor unit vector setting the height of individual panels, or a single unit for the total panel area height. Overrides aspect ratio set by the theme, coord, or facets. Defaults toNULL.